==> generator-apollo-server-with-mongodb-1.1.0.tgz: package/generators/add-model/templates/graphql/resolvers/resolver.js <==
const <%=model%> = require('../../models/<%=model%>');


module.exports = {
    Query: {
        async <%=small_models%>() {
            try {
				const <%=small_models%> = await <%=model%>.find().sort({ createdAt: -1 });
				return <%=small_models%>;
            } catch (err) {
                throw new Error(err);
            }
		},
		async <%=small_models%>_where(_, { ids }) {
            try {
				let _ids = [];
				if (ids !== undefined) _ids = ids;
                const <%=small_models%> = await <%=model%>.find().where('_id').in(_ids);
                return <%=small_models%>;
            } catch (err) {
                throw new Error(err);
            }
        },
        async <%=small_model%>(_, { id }) {
            try {
                const <%=small_model%> = await <%=model%>.findById(id);
                if (<%=small_model%>) {
                    return <%=small_model%>;
                } else {
                    throw new Error('<%=model%> not found');
                }
            } catch (err) {
                throw new Error(err);
            }
        }
	},
	Mutation: {
		async update<%=model%>(_, { id, <%= fields.map(f => f[0]).join(', ') %> }, context) {
			try {
				let item;
				if (!id || id === 'new') {
					item = new <%=model%>({
						<% fields.forEach(function(field){ %><%= field[0] %>,
						<% }) %>
						createdAt: new Date().toISOString(),
						updatedAt: new Date().toISOString()
					});
					//g-key after new
				} else {
					item = await <%=model%>.findById(id);
					<% fields.forEach(function(field){ %>if (<%= field[0] %> !== undefined) item.<%= field[0] %> = <%= field[0] %>;
					<% }) %>
					item.updatedAt =  new Date().toISOString();
				}
				await item.save();
				return item.id;
			} catch (err) {
				throw new Error(err);
			}
		},

		async delete<%=model%>(_, { id }, context) {
			try {
				const del = await <%=model%>.findById(id);
				await del.delete();
				return 'deleted successfully';
			} catch (err) {
				throw new Error(err);
			}
		},

	}
};

==> generator-apollo-server-with-mongodb-1.1.3.tgz: package/generators/add-model/templates/graphql/resolvers/resolver.js <==
const <%=model%> = require('../../models/<%=model%>');


module.exports = {
    Query: {
        async <%=small_models%>() {
            try {
				const <%=small_models%> = await <%=model%>.find().sort({ createdAt: -1 });//g-key populate
				return <%=small_models%>;
            } catch (err) {
                throw new Error(err);
            }
		},
		async <%=small_models%>_where(_, { ids }) {
            try {
				let _ids = [];
				if (ids !== undefined) _ids = ids;
                const <%=small_models%> = await <%=model%>.find().where('_id').in(_ids);//g-key populate
                return <%=small_models%>;
            } catch (err) {
                throw new Error(err);
            }
        },
        async <%=small_model%>(_, { id }) {
            try {
                const <%=small_model%> = await <%=model%>.findById(id);//g-key populate
                if (<%=small_model%>) {
                    return <%=small_model%>;
                } else {
                    throw new Error('<%=model%> not found');
                }
            } catch (err) {
                throw new Error(err);
            }
        }
	},
	Mutation: {
		async update<%=model%>(_, { id, <%= fields.map(f => f[0]).join(', ') %> }, context) {
			try {
				let item;
				if (!id || id === 'new') {
					item = new <%=model%>({
						<% fields.forEach(function(field){ %><%= field[0] %>,
						<% }) %>
						createdAt: new Date().toISOString(),
						updatedAt: new Date().toISOString()
					});
					//g-key after new
				} else {
					item = await <%=model%>.findById(id);
					<% fields.forEach(function(field){ %>if (<%= field[0] %> !== undefined) item.<%= field[0] %> = <%= field[0] %>;
					<% }) %>
					item.updatedAt =  new Date().toISOString();
				}
				await item.save();
				return item.id;
			} catch (err) {
				throw new Error(err);
			}
		},

		async delete<%=model%>(_, { id }, context) {
			try {
				const del = await <%=model%>.findById(id);
				await del.delete();
				return 'deleted successfully';
			} catch (err) {
				throw new Error(err);
			}
		},

	}
};
